# -*- perl -*-

#
#   Copyright (C) Heinz-Josef Claes (2002-2012)
#                 hjclaes@web.de
#   
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
#


$main::STOREBACKUPVERSION = "3.3.1";


sub printVersion
{
    my ($ARGV, $par) = @_;

    my ($flag) = 0;
    my ($entry);

    foreach $entry (@$ARGV)
    {
	if ($entry eq $par)
	{
	    $flag = 1;
	    last;
	}
    }
    return if ($flag == 0);

    print "version $main::STOREBACKUPVERSION\n";

    exit 0;
}


1
